@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 package Math::HexGrid;
-$Math::HexGrid::VERSION = '0.01';
+$Math::HexGrid::VERSION = '0.02';
 # ABSTRACT: Math::HexGrid - create hex coordinate grids
 
 use Math::HexGrid::Hex;
@@ -27,18 +27,61 @@ sub new_hexagon
   }
 
   bless {
-    map => \%map,
+    map  => \%map,
+    type => 'hexagon',
   }, $class;
 }
 
 
-sub get_hex
+sub new_triangle
+{
+  my ($class, $rows) = @_;
+
+  my %map;
+  for (my $q = 0; $q <= $rows; $q++)
+  {
+    for (my $r = 0; $r <= $rows - $q; $r++)
+    {
+      $map{"$q$r"} = Math::HexGrid::Hex->new($q, $r);
+    }
+  }
+  bless {
+    map  => \%map,
+    type => 'triangle',
+  }, $class;
+}
+
+
+sub hexgrid { $_[0]->{map} }
+
+
+sub hex
 {
   my ($self, $q, $r) = @_;
   $self->{map}{"$q$r"};
 }
 
 
+sub count_sides
+{
+  my ($self) = @_;
+  my $n = keys %{$self->{map}};
+
+  if ($self->{type} eq 'hexagon')
+  {
+    ($n-1) * 3 + $n-1 + 6;
+  }
+  elsif ($self->{type} eq 'triangle')
+  {
+    $n * 4 + 3;
+  }
+  else
+  {
+    die "Unknown map type!";
+  }
+}
+
+
 1;
 
 __END__
@@ -53,7 +96,7 @@ Math::HexGrid - Math::HexGrid - create hex coordinate grids
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
@@ -67,10 +110,22 @@ axial (trapezoidal) coordinate systems.
 
 Constructs a new hexagonally-shaped grid of size C<$radius>.
 
-=head2 get_hex ($q, $r)
+=head2 new_triangle ($rows)
+
+Constructs a new triangle-shaped grid with C<$rows> number of rows.
+
+=head2 hexgrid
+
+Returns a hashref of all hexes in the grid.
+
+=head2 hex ($q, $r)
 
 Returns the hex at location C<$q> and C<$r>.
 
+=head2 count_sides
+
+Returns a count of all unique sides (edges) in the grid.
+
 =head1 SEE ALSO
 
 This code was helped by Amit Patel's L<articles|http://www.redblobgames.com/grids/hexagons/> on hexagonal grids.
